# PauliCirc

[![Generic badge](https://img.shields.io/badge/python-3.10+-green.svg)](https://docs.python.org/3.10/)
[![Checked with Mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](https://github.com/python/mypy)
[![PyPI version shields.io](https://img.shields.io/pypi/v/paulicirc.svg)](https://pypi.python.org/pypi/paulicirc/)
[![PyPI status](https://img.shields.io/pypi/status/paulicirc.svg)](https://pypi.python.org/pypi/paulicirc/)

PauliCirc is a library for the creation of circuits of Pauli gadgets.

## Installation

You can install the library from PyPI as follows:

```
pip install -U paulicirc
```

## API

For the full API documentation, see https://paulicirc.readthedocs.io/

## License

[LGPLv3](./LICENSE) © NeverLocal Ltd
